@@ -511,7 +511,15 @@ struct lfExtModifier : public lfModifier
     static void ModifyCoord_Geom_ERect_Rect (void *data, float *iocoord, int count);
     static void ModifyCoord_Geom_ERect_FishEye (void *data, float *iocoord, int count);
     static void ModifyCoord_Geom_ERect_Panoramic (void *data, float *iocoord, int count);
-#if VECTORIZATION_SSE2
+    static void ModifyCoord_Geom_ERect_Orthographic (void *data, float *iocoord, int count);
+    static void ModifyCoord_Geom_Orthographic_ERect (void *data, float *iocoord, int count);
+    static void ModifyCoord_Geom_ERect_Stereographic (void *data, float *iocoord, int count);
+    static void ModifyCoord_Geom_Stereographic_ERect (void *data, float *iocoord, int count);
+    static void ModifyCoord_Geom_ERect_Equisolid (void *data, float *iocoord, int count);
+    static void ModifyCoord_Geom_Equisolid_ERect (void *data, float *iocoord, int count);
+    static void ModifyCoord_Geom_ERect_Thoby (void *data, float *iocoord, int count);
+    static void ModifyCoord_Geom_Thoby_ERect (void *data, float *iocoord, int count);
+#ifdef VECTORIZATION_SSE2
     static void ModifyColor_DeVignetting_PA_SSE2 (
       void *data, float _x, float _y, lf_u16 *pixels, int comp_role, int count);
     static void ModifyColor_DeVignetting_PA_SSE2_aligned (
